transcribe_video = """
You are generating a video summary.
Create a summary of the provided video and its transcript. 
Respond in markdown.
"""

summarize_video = """
You are generating a video summary. 
Create a summary of the provided video without the frame by frame transcription. 
Respond in markdown.
"""
